@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cu_algorithm.c 13247 2015-02-20 15:10:29Z pramsey $
+ * $Id: cu_algorithm.c 13696 2015-06-24 19:06:01Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -898,20 +898,25 @@ static void test_geohash_point_as_int(void)
 static void test_lwgeom_simplify(void)
 {
 		LWGEOM *l;
+		LWGEOM *i;
 		char *ewkt;
 
 		/* Not simplifiable */
-		l = lwgeom_simplify(lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE), 1.0);
+		i = lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE);
+		l = lwgeom_simplify(i, 1.0);
 		ewkt = lwgeom_to_ewkt(l);
 		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,50 1.00001,100 0)");
 		lwgeom_free(l);
+		lwgeom_free(i);
 		lwfree(ewkt);
 
 		/* Simplifiable */
-		l = lwgeom_simplify(lwgeom_from_wkt("LINESTRING(0 0,50 0.99999,100 0)", LW_PARSER_CHECK_NONE), 1.0);
+		i = lwgeom_from_wkt("LINESTRING(0 0,50 0.99999,100 0)", LW_PARSER_CHECK_NONE);
+		l = lwgeom_simplify(i, 1.0);
 		ewkt = lwgeom_to_ewkt(l);
 		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,100 0)");
 		lwgeom_free(l);
+		lwgeom_free(i);
 		lwfree(ewkt);
 }
 
