@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cu_out_kml.c 13134 2014-12-01 08:47:21Z strk $
+ * $Id: cu_out_kml.c 13242 2015-02-19 00:22:22Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -236,12 +236,12 @@ static void out_kml_test_prefix(void)
 /*
 ** Used by test harness to register the tests in this file.
 */
-CU_TestInfo out_kml_tests[] =
+void out_kml_suite_setup(void);
+void out_kml_suite_setup(void)
 {
-	PG_TEST(out_kml_test_precision),
-	PG_TEST(out_kml_test_dims),
-	PG_TEST(out_kml_test_geoms),
-	PG_TEST(out_kml_test_prefix),
-	CU_TEST_INFO_NULL
-};
-CU_SuiteInfo out_kml_suite = {"KML Out Suite",  NULL,  NULL, out_kml_tests};
+	CU_pSuite suite = CU_add_suite("KML Output", NULL, NULL);
+	PG_ADD_TEST(suite, out_kml_test_precision);
+	PG_ADD_TEST(suite, out_kml_test_dims);
+	PG_ADD_TEST(suite, out_kml_test_geoms);
+	PG_ADD_TEST(suite, out_kml_test_prefix);
+}
