@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cu_tester.c 13134 2014-12-01 08:47:21Z strk $
+ * $Id: cu_tester.c 13242 2015-02-19 00:22:22Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -21,36 +21,78 @@
 static void
 cu_errorreporter(const char *fmt, va_list ap);
 
-/* ADD YOUR SUITE HERE (1 of 2) */
-extern CU_SuiteInfo print_suite;
-extern CU_SuiteInfo algorithms_suite;
-extern CU_SuiteInfo buildarea_suite;
-extern CU_SuiteInfo clean_suite;
-extern CU_SuiteInfo misc_suite;
-extern CU_SuiteInfo ptarray_suite;
-extern CU_SuiteInfo measures_suite;
-extern CU_SuiteInfo node_suite;
-extern CU_SuiteInfo wkt_out_suite;
-extern CU_SuiteInfo wkt_in_suite;
-extern CU_SuiteInfo wkb_out_suite;
-extern CU_SuiteInfo wkb_in_suite;
-extern CU_SuiteInfo libgeom_suite;
-extern CU_SuiteInfo split_suite;
-extern CU_SuiteInfo geodetic_suite;
-extern CU_SuiteInfo geos_suite;
-extern CU_SuiteInfo sfcgal_suite;
-extern CU_SuiteInfo tree_suite;
-extern CU_SuiteInfo triangulate_suite;
-extern CU_SuiteInfo homogenize_suite;
-extern CU_SuiteInfo force_sfs_suite;
-extern CU_SuiteInfo in_geojson_suite;
-extern CU_SuiteInfo stringbuffer_suite;
-extern CU_SuiteInfo surface_suite;
-extern CU_SuiteInfo out_gml_suite;
-extern CU_SuiteInfo out_kml_suite;
-extern CU_SuiteInfo out_geojson_suite;
-extern CU_SuiteInfo out_svg_suite;
-extern CU_SuiteInfo out_x3d_suite;
+
+/* ADD YOUR SUITE SETUP FUNCTION HERE (1 of 2) */
+extern void print_suite_setup();
+extern void algorithms_suite_setup();
+extern void buildarea_suite_setup();
+extern void clean_suite_setup();
+extern void force_sfs_suite_setup(void);
+extern void geodetic_suite_setup(void);
+extern void geos_suite_setup(void);
+extern void homogenize_suite_setup(void);
+extern void in_geojson_suite_setup(void);
+extern void libgeom_suite_setup(void);
+extern void measures_suite_setup(void);
+extern void misc_suite_setup(void);
+extern void node_suite_setup(void);
+extern void out_geojson_suite_setup(void);
+extern void out_gml_suite_setup(void);
+extern void out_kml_suite_setup(void);
+extern void out_svg_suite_setup(void);
+extern void out_x3d_suite_setup(void);
+extern void ptarray_suite_setup(void);
+extern void sfcgal_suite_setup(void);
+extern void split_suite_setup(void);
+extern void stringbuffer_suite_setup(void);
+extern void tree_suite_setup(void);
+extern void triangulate_suite_setup(void);
+extern void wkt_out_suite_setup(void);
+extern void wkb_out_suite_setup(void);
+extern void surface_suite_setup(void);
+extern void wkb_in_suite_setup(void);
+extern void wkt_in_suite_setup(void);
+
+
+/* AND ADD YOUR SUITE SETUP FUNCTION HERE (2 of 2) */
+PG_SuiteSetup setupfuncs[] =
+{
+	print_suite_setup,
+	algorithms_suite_setup,
+	buildarea_suite_setup,
+	clean_suite_setup,
+	force_sfs_suite_setup,
+	geodetic_suite_setup,
+	geos_suite_setup,
+	homogenize_suite_setup,
+#if HAVE_LIBJSON
+	in_geojson_suite_setup,
+#endif
+	libgeom_suite_setup,
+	measures_suite_setup,
+	misc_suite_setup,
+	node_suite_setup,
+	out_geojson_suite_setup,
+	out_gml_suite_setup,
+	out_kml_suite_setup,
+	out_svg_suite_setup,
+	out_x3d_suite_setup,
+	ptarray_suite_setup,
+#if HAVE_SFCGAL
+	sfcgal_suite_setup,
+#endif
+	split_suite_setup,
+	stringbuffer_suite_setup,
+	tree_suite_setup,
+	triangulate_suite_setup,
+	wkt_out_suite_setup,
+	wkb_out_suite_setup,
+	surface_suite_setup,
+	wkb_in_suite_setup,
+	wkt_in_suite_setup,
+	NULL
+};
+
 
 /*
 ** The main() function for setting up and running the tests.
@@ -59,45 +101,6 @@ extern CU_SuiteInfo out_x3d_suite;
 */
 int main(int argc, char *argv[])
 {
-	/* ADD YOUR SUITE HERE (2 of 2) */
-	CU_SuiteInfo suites[] =
-	{
-		print_suite,
-		misc_suite,
-		ptarray_suite,
-		algorithms_suite,
-		buildarea_suite,
-		clean_suite,
-		measures_suite,
-		node_suite,
-		wkt_out_suite,
-		wkt_in_suite,
-		wkb_out_suite,
-		wkb_in_suite,
-		libgeom_suite,
-		split_suite,
-		geodetic_suite,
-		geos_suite,
-#if HAVE_SFCGAL
-		sfcgal_suite,
-#endif
-		tree_suite,
-		triangulate_suite,
-		stringbuffer_suite,
-		surface_suite,
-		homogenize_suite,
-		force_sfs_suite,
-#if HAVE_JSON
-		in_geojson_suite,
-#endif
-		out_gml_suite,
-		out_kml_suite,
-		out_geojson_suite,
-		out_svg_suite,
-		out_x3d_suite,
-		CU_SUITE_INFO_NULL
-	};
-
 	int index;
 	char *suite_name;
 	CU_pSuite suite_to_run;
@@ -107,7 +110,8 @@ int main(int argc, char *argv[])
 	CU_pTestRegistry registry;
 	int num_run;
 	int num_failed;
-
+        PG_SuiteSetup *setupfunc = setupfuncs;
+	
 	/* install the custom error handler */
 	lwgeom_set_handlers(0, 0, 0, cu_errorreporter, 0);
 
@@ -120,13 +124,13 @@ int main(int argc, char *argv[])
 	}
 
 	/* Register all the test suites. */
-	if (CUE_SUCCESS != CU_register_suites(suites))
+        while ( *setupfunc )
 	{
-		errCode = CU_get_error();
-		printf("    Error attempting to register test suites: %d.  See CUError.h for error code list.\n", errCode);
-		return errCode;
+		(*setupfunc)();
+		setupfunc++;
 	}
 
+
 	/* Run all tests using the CUnit Basic interface */
 	CU_basic_set_mode(CU_BRM_VERBOSE);
 	if (argc <= 1)
