@@ -80,6 +80,11 @@ circ_node_leaf_new(const POINTARRAY* pa, int i)
 	node->num_nodes = 0;
 	node->nodes = NULL;
 	node->edge_num = i;
+    
+    /* Zero out metadata */
+    node->pt_outside.x = 0.0;
+    node->pt_outside.y = 0.0;
+    node->geom_type = 0;
 	
 	return node;
 }
@@ -97,6 +102,9 @@ circ_node_leaf_point_new(const POINTARRAY* pa)
 	tree->nodes = NULL;
 	tree->num_nodes = 0;
 	tree->edge_num = 0;
+    tree->geom_type = POINTTYPE;
+    tree->pt_outside.x = 0.0;
+    tree->pt_outside.y = 0.0;
 	return tree;
 }
 
@@ -109,8 +117,8 @@ circ_node_compare(const void* v1, const void* v2)
 {
 	POINT2D p1, p2;
 	unsigned int u1, u2;
-	CIRC_NODE *c1 = (CIRC_NODE*)v1;
-	CIRC_NODE *c2 = (CIRC_NODE*)v2;
+	CIRC_NODE *c1 = *((CIRC_NODE**)v1);
+	CIRC_NODE *c2 = *((CIRC_NODE**)v2);
 	p1.x = rad2deg((c1->center).lon);
 	p1.y = rad2deg((c1->center).lat);
 	p2.x = rad2deg((c2->center).lon);
@@ -199,7 +207,7 @@ circ_node_internal_new(CIRC_NODE** c, int num_nodes)
 	GEOGRAPHIC_POINT new_center, c1;
 	double new_radius;
 	double offset1, dist, D, r1, ri;
-	int i;
+	int i, new_geom_type;
 
 	LWDEBUGF(3, "called with %d nodes --", num_nodes);
 
@@ -210,6 +218,7 @@ circ_node_internal_new(CIRC_NODE** c, int num_nodes)
 	/* Initialize calculation with values of the first circle */
 	new_center = c[0]->center;
 	new_radius = c[0]->radius;
+	new_geom_type = c[0]->geom_type;
 	
 	/* Merge each remaining circle into the new circle */
 	for ( i = 1; i < num_nodes; i++ )
@@ -220,6 +229,32 @@ circ_node_internal_new(CIRC_NODE** c, int num_nodes)
 		dist = sphere_distance(&c1, &(c[i]->center));
 		ri = c[i]->radius;
 
+		/* Promote geometry types up the tree, getting more and more collected */
+		/* Go until we find a value */
+		if ( ! new_geom_type )
+		{
+			new_geom_type = c[i]->geom_type;
+		}
+		/* Promote singleton to a multi-type */
+		else if ( ! lwtype_is_collection(new_geom_type) )
+		{
+			/* Anonymous collection if types differ */
+			if ( new_geom_type != c[i]->geom_type )
+			{
+				new_geom_type = COLLECTIONTYPE;
+			}
+			else
+			{
+				new_geom_type = lwtype_get_collectiontype(new_geom_type);				
+			}
+		}
+		/* If we can't add next feature to this collection cleanly, promote again to anonymous collection */
+		else if ( new_geom_type != lwtype_get_collectiontype(c[i]->geom_type) )
+		{
+			new_geom_type = COLLECTIONTYPE;
+		}
+
+
 		LWDEBUGF(3, "distance between new (%g %g) and %i (%g %g) is %g", c1.lon, c1.lat, i, c[i]->center.lon, c[i]->center.lat, dist);
 		
 		if ( FP_EQUALS(dist, 0) )
@@ -280,13 +315,14 @@ circ_node_internal_new(CIRC_NODE** c, int num_nodes)
 	node->num_nodes = num_nodes;
 	node->nodes = c;
 	node->edge_num = -1;
+    node->geom_type = new_geom_type;
+    node->pt_outside.x = 0.0;
+    node->pt_outside.y = 0.0;
 	return node;
 }
 
 /**
-* Build a tree of nodes from a point array, one node per edge, and each
-* with an associated measure range along a one-dimensional space. We
-* can then search that space as a range tree.
+* Build a tree of nodes from a point array, one node per edge.
 */
 CIRC_NODE* 
 circ_tree_new(const POINTARRAY* pa)
@@ -352,6 +388,9 @@ circ_nodes_merge(CIRC_NODE** nodes, int num_nodes)
 	int num_parents = 0;
 	int j;
 
+	// TODO, roll geom_type *up* as tree is built, changing to collection types as simple types are merged 
+	// TODO, change the distance algorithm to drive down to simple types first, test pip on poly/other cases, then test edges
+
 	while( num_children > 1 )
 	{
 		for ( j = 0; j < num_children; j++ )
@@ -388,6 +427,24 @@ circ_nodes_merge(CIRC_NODE** nodes, int num_nodes)
 }
 
 
+/**
+* Returns a #POINT2D that is a vertex of the input shape
+*/
+int circ_tree_get_point(const CIRC_NODE* node, POINT2D* pt)
+{
+	if ( circ_node_is_leaf(node) )
+    {
+        pt->x = node->p1->x;
+        pt->y = node->p1->y;
+        return LW_SUCCESS;
+    }
+    else
+    {
+        return circ_tree_get_point(node->nodes[0], pt);
+    }
+}
+
+
 /**
 * Walk the tree and count intersections between the stab line and the edges.
 * odd => containment, even => no containment.
@@ -498,13 +555,19 @@ circ_tree_distance_tree(const CIRC_NODE* n1, const CIRC_NODE* n2, const SPHEROID
 	double min_dist = MAXFLOAT;
 	double max_dist = MAXFLOAT;
 	GEOGRAPHIC_POINT closest1, closest2;
-	double distance2;
 	double threshold_radians = threshold / spheroid->radius;
 	
 	circ_tree_distance_tree_internal(n1, n2, threshold_radians, &min_dist, &max_dist, &closest1, &closest2);
-	distance2 = spheroid_distance(&closest1, &closest2, spheroid);
 
-	return distance2;
+	/* Spherical case */
+	if ( spheroid->a == spheroid->b )
+	{
+		return spheroid->radius * sphere_distance(&closest1, &closest2);
+	}
+	else
+	{
+		return spheroid_distance(&closest1, &closest2, spheroid);		
+	}
 }
 
 static double 
@@ -514,12 +577,12 @@ circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, doubl
 	double d, d_min;
 	int i;
 	
-	LWDEBUGF(4, "entered, min_dist %.8g max_dist %.8g", *min_dist, *max_dist);
+	LWDEBUGF(4, "entered, min_dist=%.8g max_dist=%.8g, type1=%d, type2=%d", *min_dist, *max_dist, n1->geom_type, n2->geom_type);
 //	circ_tree_print(n1, 0);
 //	circ_tree_print(n2, 0);
 	
 	/* Short circuit if we've already hit the minimum */
-	if( FP_LT(*min_dist, threshold) )
+	if( *min_dist <= threshold )
 		return *min_dist;
 	
 	/* If your minimum is greater than anyone's maximum, you can't hold the winner */
@@ -535,127 +598,204 @@ circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, doubl
 	if( max < *max_dist )
 		*max_dist = max;
 
-	/* Both leaf nodes, do a real distance calculation */
-	if( circ_node_is_leaf(n1) )
+	/* Polygon on one side, primitive type on the other. Check for point-in-polygon */
+	/* short circuit. */
+	if ( n1->geom_type == POLYGONTYPE && n2->geom_type && ! lwtype_is_collection(n2->geom_type) )
 	{
-		if( circ_node_is_leaf(n2) )
+		POINT2D pt;
+		circ_tree_get_point(n2, &pt);
+		LWDEBUGF(4, "n1 is polygon, testing if contains (%.5g,%.5g)", pt.x, pt.y);
+		if ( circ_tree_contains_point(n1, &pt, &(n1->pt_outside), NULL) )
 		{
-			double d;
-			GEOGRAPHIC_POINT close1, close2;
-			LWDEBUGF(4, "testing leaf pair [%d], [%d]", n1->edge_num, n2->edge_num);		
-			/* One of the nodes is a point */
-			if ( n1->p1 == n1->p2 || n2->p1 == n2->p2 )
-			{
-				GEOGRAPHIC_EDGE e;
-				GEOGRAPHIC_POINT gp1, gp2;
+			LWDEBUG(4, "it does");
+			*min_dist = 0.0;
+			geographic_point_init(pt.x, pt.y, closest1);
+			geographic_point_init(pt.x, pt.y, closest2);
+			return *min_dist;
+		}			
+	}
+	/* Polygon on one side, primitive type on the other. Check for point-in-polygon */
+	/* short circuit. */
+	if ( n2->geom_type == POLYGONTYPE && n1->geom_type && ! lwtype_is_collection(n1->geom_type) )
+	{
+		POINT2D pt;
+		circ_tree_get_point(n1, &pt);
+		LWDEBUGF(4, "n2 is polygon, testing if contains (%.5g,%.5g)", pt.x, pt.y);
+		if ( circ_tree_contains_point(n2, &pt, &(n2->pt_outside), NULL) )
+		{
+			LWDEBUG(4, "it does");
+			geographic_point_init(pt.x, pt.y, closest1);
+			geographic_point_init(pt.x, pt.y, closest2);
+			*min_dist = 0.0;
+			return *min_dist;
+		}		
+	}
+	
+	/* Both leaf nodes, do a real distance calculation */
+	if( circ_node_is_leaf(n1) && circ_node_is_leaf(n2) )
+	{
+		double d;
+		GEOGRAPHIC_POINT close1, close2;
+		LWDEBUGF(4, "testing leaf pair [%d], [%d]", n1->edge_num, n2->edge_num);		
+		/* One of the nodes is a point */
+		if ( n1->p1 == n1->p2 || n2->p1 == n2->p2 )
+		{
+			GEOGRAPHIC_EDGE e;
+			GEOGRAPHIC_POINT gp1, gp2;
 
-				/* Both nodes are points! */
-				if ( n1->p1 == n1->p2 && n2->p1 == n2->p2 )
-				{
-					geographic_point_init(n1->p1->x, n1->p1->y, &gp1);
-					geographic_point_init(n2->p1->x, n2->p1->y, &gp2);
-					close1 = gp1; close2 = gp2;
-					d = sphere_distance(&gp1, &gp2);
-				}				
-				/* Node 1 is a point */
-				else if ( n1->p1 == n1->p2 )
-				{
-					geographic_point_init(n1->p1->x, n1->p1->y, &gp1);
-					geographic_point_init(n2->p1->x, n2->p1->y, &(e.start));
-					geographic_point_init(n2->p2->x, n2->p2->y, &(e.end));
-					close1 = gp1;
-					d = edge_distance_to_point(&e, &gp1, &close2);
-				}
-				/* Node 2 is a point */
-				else
-				{
-					geographic_point_init(n2->p1->x, n2->p1->y, &gp1);
-					geographic_point_init(n1->p1->x, n1->p1->y, &(e.start));
-					geographic_point_init(n1->p2->x, n1->p2->y, &(e.end));
-					close1 = gp1;
-					d = edge_distance_to_point(&e, &gp1, &close2);
-				}
-				LWDEBUGF(4, "  got distance %g", d);		
+			/* Both nodes are points! */
+			if ( n1->p1 == n1->p2 && n2->p1 == n2->p2 )
+			{
+				geographic_point_init(n1->p1->x, n1->p1->y, &gp1);
+				geographic_point_init(n2->p1->x, n2->p1->y, &gp2);
+				close1 = gp1; close2 = gp2;
+				d = sphere_distance(&gp1, &gp2);
+			}				
+			/* Node 1 is a point */
+			else if ( n1->p1 == n1->p2 )
+			{
+				geographic_point_init(n1->p1->x, n1->p1->y, &gp1);
+				geographic_point_init(n2->p1->x, n2->p1->y, &(e.start));
+				geographic_point_init(n2->p2->x, n2->p2->y, &(e.end));
+				close1 = gp1;
+				d = edge_distance_to_point(&e, &gp1, &close2);
 			}
-			/* Both nodes are edges */
+			/* Node 2 is a point */
 			else
 			{
-				GEOGRAPHIC_EDGE e1, e2;
-				GEOGRAPHIC_POINT g;
-				POINT3D A1, A2, B1, B2;
-				geographic_point_init(n1->p1->x, n1->p1->y, &(e1.start));
-				geographic_point_init(n1->p2->x, n1->p2->y, &(e1.end));
-				geographic_point_init(n2->p1->x, n2->p1->y, &(e2.start));
-				geographic_point_init(n2->p2->x, n2->p2->y, &(e2.end));
-				geog2cart(&(e1.start), &A1);
-				geog2cart(&(e1.end), &A2);
-				geog2cart(&(e2.start), &B1);
-				geog2cart(&(e2.end), &B2);
-				if ( edge_intersects(&A1, &A2, &B1, &B2) )
-				{
-					d = 0.0;
-					edge_intersection(&e1, &e2, &g);
-					close1 = close2 = g;
-				}
-				else
-				{
-					d = edge_distance_to_edge(&e1, &e2, &close1, &close2);
-				}
-				LWDEBUGF(4, "edge_distance_to_edge returned %g", d);		
+				geographic_point_init(n2->p1->x, n2->p1->y, &gp1);
+				geographic_point_init(n1->p1->x, n1->p1->y, &(e.start));
+				geographic_point_init(n1->p2->x, n1->p2->y, &(e.end));
+				close1 = gp1;
+				d = edge_distance_to_point(&e, &gp1, &close2);
 			}
-			if ( d < *min_dist )
-			{
-				*min_dist = d;
-				*closest1 = close1;
-				*closest2 = close2;
-			}
-			return d;
+			LWDEBUGF(4, "  got distance %g", d);		
 		}
+		/* Both nodes are edges */
 		else
 		{
-			d_min = MAXFLOAT;
+			GEOGRAPHIC_EDGE e1, e2;
+			GEOGRAPHIC_POINT g;
+			POINT3D A1, A2, B1, B2;
+			geographic_point_init(n1->p1->x, n1->p1->y, &(e1.start));
+			geographic_point_init(n1->p2->x, n1->p2->y, &(e1.end));
+			geographic_point_init(n2->p1->x, n2->p1->y, &(e2.start));
+			geographic_point_init(n2->p2->x, n2->p2->y, &(e2.end));
+			geog2cart(&(e1.start), &A1);
+			geog2cart(&(e1.end), &A2);
+			geog2cart(&(e2.start), &B1);
+			geog2cart(&(e2.end), &B2);
+			if ( edge_intersects(&A1, &A2, &B1, &B2) )
+			{
+				d = 0.0;
+				edge_intersection(&e1, &e2, &g);
+				close1 = close2 = g;
+			}
+			else
+			{
+				d = edge_distance_to_edge(&e1, &e2, &close1, &close2);
+			}
+			LWDEBUGF(4, "edge_distance_to_edge returned %g", d);		
+		}
+		if ( d < *min_dist )
+		{
+			*min_dist = d;
+			*closest1 = close1;
+			*closest2 = close2;
+		}
+		return d;
+	}
+	else
+	{	
+		d_min = MAXFLOAT;
+		/* Drive the recursion into the COLLECTION types first so we end up with */
+		/* pairings of primitive geometries that can be forced into the point-in-polygon */
+		/* tests above. */
+		if ( n1->geom_type && lwtype_is_collection(n1->geom_type) )
+		{
+			for ( i = 0; i < n1->num_nodes; i++ )
+			{
+				d = circ_tree_distance_tree_internal(n1->nodes[i], n2, threshold, min_dist, max_dist, closest1, closest2);
+				d_min = FP_MIN(d_min, d);
+			}
+		}
+		else if ( n2->geom_type && lwtype_is_collection(n2->geom_type) )
+		{
 			for ( i = 0; i < n2->num_nodes; i++ )
 			{
 				d = circ_tree_distance_tree_internal(n1, n2->nodes[i], threshold, min_dist, max_dist, closest1, closest2);
 				d_min = FP_MIN(d_min, d);
 			}
-			return d_min;
 		}
-	}
-	else
-	{
-		d_min = MAXFLOAT;
-		for ( i = 0; i < n1->num_nodes; i++ )
+		else if ( ! circ_node_is_leaf(n1) )
 		{
-			d = circ_tree_distance_tree_internal(n2, n1->nodes[i], threshold, min_dist, max_dist, closest1, closest2);
-			d_min = FP_MIN(d_min, d);
+			for ( i = 0; i < n1->num_nodes; i++ )
+			{
+				d = circ_tree_distance_tree_internal(n1->nodes[i], n2, threshold, min_dist, max_dist, closest1, closest2);
+				d_min = FP_MIN(d_min, d);
+			}
 		}
+		else if ( ! circ_node_is_leaf(n2) )
+		{
+			for ( i = 0; i < n2->num_nodes; i++ )
+			{
+				d = circ_tree_distance_tree_internal(n1, n2->nodes[i], threshold, min_dist, max_dist, closest1, closest2);
+				d_min = FP_MIN(d_min, d);
+			}
+		}
+		else
+		{
+			/* Never get here */
+		}
+		
 		return d_min;
 	}
 }
 
 
+
+
+
 void circ_tree_print(const CIRC_NODE* node, int depth)
 {
 	int i;
-	
-	if ( node->num_nodes > 0 ) 
+
+	if (circ_node_is_leaf(node))
 	{
-		printf("%*s C(%.5g %.5g) R(%.5g)\n", 
-		  3*depth + 6, "NODE", 
-		  node->center.lon, node->center.lat,
-		  node->radius
-		);
-	}
-	else
-	{
-		printf("%*s[%d] C(%.5g %.5g) R(%.5g) ((%.5g %.5g),(%.5g,%.5g))\n", 
+		printf("%*s[%d] C(%.5g %.5g) R(%.5g) ((%.5g %.5g),(%.5g,%.5g))", 
 		  3*depth + 6, "NODE", node->edge_num,
 		  node->center.lon, node->center.lat,
 		  node->radius,
 		  node->p1->x, node->p1->y,
 		  node->p2->x, node->p2->y
 		);
+  		if ( node->geom_type )
+  		{
+  			printf(" %s", lwtype_name(node->geom_type));
+  		}		
+  		if ( node->geom_type == POLYGONTYPE )
+  		{
+  			printf(" O(%.5g %.5g)", node->pt_outside.x, node->pt_outside.y);
+  		}				
+  		printf("\n");
+		  
+	}	
+	else
+	{
+		printf("%*s C(%.5g %.5g) R(%.5g)", 
+		  3*depth + 6, "NODE", 
+		  node->center.lon, node->center.lat,
+		  node->radius
+		);
+		if ( node->geom_type )
+		{
+			printf(" %s", lwtype_name(node->geom_type));
+		}
+  		if ( node->geom_type == POLYGONTYPE )
+  		{
+  			printf(" O(%.5g %.5g)", node->pt_outside.x, node->pt_outside.y);
+  		}		
+		printf("\n");
 	}
 	for ( i = 0; i < node->num_nodes; i++ )
 	{
@@ -668,13 +808,19 @@ void circ_tree_print(const CIRC_NODE* node, int depth)
 static CIRC_NODE*
 lwpoint_calculate_circ_tree(const LWPOINT* lwpoint)
 {
-	return circ_tree_new(lwpoint->point);
+	CIRC_NODE* node;
+    node = circ_tree_new(lwpoint->point);
+    node->geom_type = lwgeom_get_type((LWGEOM*)lwpoint);;
+	return node;
 }
 
 static CIRC_NODE*
 lwline_calculate_circ_tree(const LWLINE* lwline)
 {
-	return circ_tree_new(lwline->points);
+	CIRC_NODE* node;
+    node = circ_tree_new(lwline->points);
+    node->geom_type = lwgeom_get_type((LWGEOM*)lwline);
+	return node;
 }
 
 static CIRC_NODE*
@@ -686,22 +832,31 @@ lwpoly_calculate_circ_tree(const LWPOLY* lwpoly)
 
 	/* One ring? Handle it like a line. */
 	if ( lwpoly->nrings == 1 )
-		return circ_tree_new(lwpoly->rings[0]);	
-	
-	/* Calculate a tree for each non-trivial ring of the polygon */
-	nodes = lwalloc(lwpoly->nrings * sizeof(CIRC_NODE*));
-	for ( i = 0; i < lwpoly->nrings; i++ )
 	{
-		node = circ_tree_new(lwpoly->rings[i]);
-		if ( node )
-			nodes[j++] = node;
+		node = circ_tree_new(lwpoly->rings[0]);			
 	}
-	/* Put the trees into a spatially correlated order */
-	circ_nodes_sort(nodes, j);
-	/* Merge the trees pairwise up to a parent node and return */
-	node = circ_nodes_merge(nodes, j);
-	/* Don't need the working list any more */
-	lwfree(nodes);
+	else
+	{
+		/* Calculate a tree for each non-trivial ring of the polygon */
+		nodes = lwalloc(lwpoly->nrings * sizeof(CIRC_NODE*));
+		for ( i = 0; i < lwpoly->nrings; i++ )
+		{
+			node = circ_tree_new(lwpoly->rings[i]);
+			if ( node )
+				nodes[j++] = node;
+		}
+		/* Put the trees into a spatially correlated order */
+		circ_nodes_sort(nodes, j);
+		/* Merge the trees pairwise up to a parent node and return */
+		node = circ_nodes_merge(nodes, j);
+		/* Don't need the working list any more */
+		lwfree(nodes);
+	}
+
+	/* Metatdata about polygons, we need this to apply P-i-P tests */
+	/* selectively when doing distance calculations */
+    node->geom_type = lwgeom_get_type((LWGEOM*)lwpoly);
+	lwpoly_pt_outside(lwpoly, &(node->pt_outside));
 	
 	return node;
 }
@@ -732,6 +887,8 @@ lwcollection_calculate_circ_tree(const LWCOLLECTION* lwcol)
 	/* Don't need the working list any more */
 	lwfree(nodes);
 	
+    node->geom_type = lwgeom_get_type((LWGEOM*)lwcol);
+    
 	return node;
 }
 
