@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeom_box.c 13134 2014-12-01 08:47:21Z strk $
+ * $Id: lwgeom_box.c 13391 2015-03-23 16:34:30Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -52,12 +52,6 @@ Datum BOX2D_in(PG_FUNCTION_ARGS)
 	
 	gbox_init(&box);
 
-	if (strcasestr(str,"BOX(") !=  str )
-	{
-		elog(ERROR,"box2d parser - doesnt start with BOX(");
-		PG_RETURN_NULL();
-	}
-	
 	for(i = 0; str[i]; i++) {
 	  str[i] = tolower(str[i]);
 	}
