@@ -112,8 +112,12 @@ int getSRIDbySRS(const char* srs)
 		SPI_finish();
 		return 0;
 	}
-	sprintf(query, "SELECT srid \
-	        FROM spatial_ref_sys WHERE auth_name||':'||auth_srid = '%s'", srs);
+
+	sprintf(query, 
+		"SELECT srid "
+		"FROM spatial_ref_sys, "
+		"regexp_matches('%s', E'([a-z]+):([0-9]+)', 'gi') AS re "
+		"WHERE re[1] ILIKE auth_name AND int4(re[2]) = auth_srid", srs);
 
 	err = SPI_exec(query, 1);
 	if ( err < 0 )
@@ -126,9 +130,11 @@ int getSRIDbySRS(const char* srs)
 	/* no entry in spatial_ref_sys */
 	if (SPI_processed <= 0)
 	{
-		sprintf(query, "SELECT srid \
-		        FROM spatial_ref_sys WHERE \
-		        'urn:ogc:def:crs:'||auth_name||'::'||auth_srid = '%s'", srs);
+		sprintf(query, 
+			"SELECT srid "
+			"FROM spatial_ref_sys, "
+			"regexp_matches('%s', E'urn:ogc:def:crs:([a-z]+):.*:([0-9]+)', 'gi') AS re "
+			"WHERE re[1] ILIKE auth_name AND int4(re[2]) = auth_srid", srs);
 
 		err = SPI_exec(query, 1);
 		if ( err < 0 )
@@ -176,8 +182,10 @@ Datum LWGEOM_asGML(PG_FUNCTION_ARGS)
 	static const char* default_prefix = "gml:"; /* default prefix */
 	const char* prefix = default_prefix;
 	const char* gml_id = NULL;
-	char *prefix_buf, *gml_id_buf;
+	size_t len;
+	char *gml_id_buf, *prefix_buf;
 	text *prefix_text, *gml_id_text;
+	
 
 	/* Get the version */
 	version = PG_GETARG_INT32(0);
@@ -209,19 +217,18 @@ Datum LWGEOM_asGML(PG_FUNCTION_ARGS)
 	if (PG_NARGS() >4 && !PG_ARGISNULL(4))
 	{
 		prefix_text = PG_GETARG_TEXT_P(4);
-		if ( VARSIZE(prefix_text)-VARHDRSZ == 0 )
+		if ( VARSIZE(prefix_text) == VARHDRSZ )
 		{
 			prefix = "";
 		}
 		else
 		{
-			/* +2 is one for the ':' and one for term null */
-			prefix_buf = palloc(VARSIZE(prefix_text)-VARHDRSZ+2);
-			memcpy(prefix_buf, VARDATA(prefix_text),
-			       VARSIZE(prefix_text)-VARHDRSZ);
+			len = VARSIZE(prefix_text)-VARHDRSZ;
+			prefix_buf = palloc(len + 2); /* +2 is one for the ':' and one for term null */
+			memcpy(prefix_buf, VARDATA(prefix_text), len);
 			/* add colon and null terminate */
-			prefix_buf[VARSIZE(prefix_text)-VARHDRSZ] = ':';
-			prefix_buf[VARSIZE(prefix_text)-VARHDRSZ+1] = '\0';
+			prefix_buf[len] = ':';
+			prefix_buf[len+1] = '\0';
 			prefix = prefix_buf;
 		}
 	}
@@ -229,15 +236,16 @@ Datum LWGEOM_asGML(PG_FUNCTION_ARGS)
 	if (PG_NARGS() >5 && !PG_ARGISNULL(5))
 	{
 		gml_id_text = PG_GETARG_TEXT_P(5);
-		if ( VARSIZE(gml_id_text)-VARHDRSZ == 0 )
+		if ( VARSIZE(gml_id_text) == VARHDRSZ )
 		{
 			gml_id = "";
 		}
 		else
 		{
-			gml_id_buf = palloc(VARSIZE(gml_id_text)-VARHDRSZ+1);
-			memcpy(gml_id_buf, VARDATA(gml_id_text), VARSIZE(gml_id_text)-VARHDRSZ);
-			gml_id_buf[VARSIZE(gml_id_text)-VARHDRSZ+1] = '\0';
+			len = VARSIZE(gml_id_text)-VARHDRSZ;
+			gml_id_buf = palloc(len+1);
+			memcpy(gml_id_buf, VARDATA(gml_id_text), len);
+			gml_id_buf[len] = '\0';
 			gml_id = gml_id_buf;
 		}
 	}
