@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeom_functions_basic.c 13371 2015-03-20 15:32:06Z pramsey $
+ * $Id: lwgeom_functions_basic.c 13659 2015-06-11 19:47:14Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -2540,8 +2540,11 @@ Datum LWGEOM_affine(PG_FUNCTION_ARGS)
 	lwgeom_affine(lwgeom, &affine);
 
 	/* COMPUTE_BBOX TAINTING */
-	lwgeom_drop_bbox(lwgeom);
-	lwgeom_add_bbox(lwgeom);
+	if ( lwgeom->bbox )
+	{
+		lwgeom_drop_bbox(lwgeom);
+		lwgeom_add_bbox(lwgeom);
+	}
 	ret = geometry_serialize(lwgeom);
 
 	/* Release memory */
